@@ -16,12 +16,12 @@ from itertools import combinations as comb
 import numpy as np
 from prettytable import PrettyTable, PLAIN_COLUMNS
 
-from cdftpy.cdft1d.config import DATA_DIR
+from cdftpy.cdft1d.globals import DATA_DIR
 from cdftpy.cdft1d.io_utils import read_array
 from cdftpy.cdft1d.io_utils import read_key_value
 from cdftpy.cdft1d.io_utils import read_molecule
-from cdftpy.utils.rad_fft import RadFFT, fft_rgrid_iv
-from cdftpy.utils.units import hartree_2_kjmol, bohr_2_ang
+from cdftpy.cdft1d.rad_fft import RadFFT, fft_rgrid_iv
+from cdftpy.cdft1d.units import hartree_2_kjmol, bohr_2_ang
 
 logging.basicConfig(level=logging.INFO)
 
@@ -240,7 +240,7 @@ class Solvent(Molecule):
         nv = self.nv
         print(f"Solvent:", file=sp)
         print(f"  model: {self.model}", file=sp)
-        print(f"  file: {self.filename}", file=sp)
+        print(f"  file: {os.path.relpath(self.filename)}", file=sp)
         tbl = PrettyTable()
         tbl.set_style(PLAIN_COLUMNS)
         tbl.field_names = ["site", "sigma(Å)", "epsilon(kj/mol)", "charge"]
@@ -343,10 +343,3 @@ def extend(solvent0, rmax):
         return solvent
 
     return solvent0
-
-if __name__ == "__main__":
-
-    solvent_name = "s2"
-    filename = solvent_model_locate(solvent_name)
-    slv0 = Solvent.from_file(filename, rism_patch=True)
-    print(slv0.to_string())
\ No newline at end of file
